@@ -7,3 +7,9 @@ from .resource import *
 from .sentence import Sentence
 from .list import List
 from .list_operators import Union, Intersection, And, Or, First, Last, Sort
+
+from . import resource
+
+__all__ = resource.__all__ + ['AbstractNode', 'Triple', 'Missing',
+        'Sentence', 'List', 'Union', 'Intersection', 'And', 'Or',
+        'First', 'Last', 'Sort']
