@@ -4,7 +4,8 @@ from ..log import logger
 from .abstractnode import register, AbstractNode
 
 __all__ = ['Resource', 'StringResource', 'MathLatexResource',
-           'BooleanResource', 'TimeResource', 'GeojsonResource']
+           'BooleanResource', 'TimeResource',
+           'JsonldResource']
 
 EXTRA_ATTRIBUTES = {
         'string': ('language',),
@@ -108,16 +109,33 @@ def freeze_dicts(d):
         return d
 
 @register_valuetype
-class GeojsonResource(Resource):
-    _value_type = 'geo-json'
-    _possible_attributes = Resource._possible_attributes + ('geojson',)
+class JsonldResource(Resource):
+    _value_type = 'resource-jsonld'
+    _possible_attributes = Resource._possible_attributes + ('graph',)
 
     @classmethod
     def deserialize_attribute(cls, key, value):
-        if key == 'geojson':
+        if key == 'graph':
             return value
         else:
             super().deserialize_attribute(key, value)
 
     def __hash__(self):
-        return hash(freeze_dicts(self._attributes))
+        raise TypeError('%s instances are not hashable.' % self.__class__)
+
+    def get_uris(self):
+        uris = set()
+        if '@id' in self.graph:
+            uris.add(self.graph['@id'])
+        same_as = self.graph.get('sameAs', [])
+        if isinstance(same_as, str):
+            same_as = [same_as]
+        assert isinstance(same_as, list)
+        uris.update(same_as)
+        return uris
+
+    def __eq__(self, other):
+        if not isinstance(other, JsonldResource):
+            return False
+        return self.graph == other.graph or \
+                bool(self.get_uris() & other.get_uris())
